Ext.namespace("dSA", "dSA.functions");

dSA.functions.ReregisterDevices = function(dsuid)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/dsm/restartRegistration',
        disableCaching: true,
        method: 'GET',
        params: { dsuid : dsuid },
        success: function(response, opts)
        {
            try
            {
                dSA.util.checkResponse(response);
                dSA.MessageBus.fireEvent('statusmessage',
                    dSA._("Device registration restarted"));
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not reregister devices") +
                    dSA.util.colon(error));
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not reregister devices") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
        }
    });
};

// callback(success, task_id)
dSA.functions.CheckTransmissionQuality = function(dsuid, checksPerDevice,
                                                  callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/hardware/testDeviceTransmissionQuality',
        disableCaching: true,
        method: 'GET',
        params:
        {
            dsm : dsuid,
            checksPerDevice: checksPerDevice
        },
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (data.task === undefined)
                {
                    throw "received invalid task id";
                }

                if (callback !== undefined)
                {
                    callback(true, data.task);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not start transmission quality test") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not start transmission quality test") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });

};

// callback(taskObject)
dSA.functions.getTaskResultSummary = function(taskID, callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/tasks/resultSummary',
        disableCaching: true,
        method: 'GET',
        params:
        {
            id : taskID
        },
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (data.task === undefined)
                {
                    throw "received unexpected reply";
                }

                if (callback !== undefined)
                {
                    callback(true, data.task);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not retrieve task summary") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not retrieve task summary") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });

};

// callback(success, task_id)
dSA.functions.CheckDevicePresence = function(dsuid, interval,
                                                  callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/hardware/testDevicePresence',
        disableCaching: true,
        method: 'GET',
        params:
        {
            dsm : dsuid,
            interval : interval
        },
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (data.task === undefined)
                {
                    throw "received invalid task id";
                }

                if (callback !== undefined)
                {
                    callback(true, data.task);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not start device presence test") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not start device presence test") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

// callback(success, present)
dSA.functions.CheckSingleDevicePresence = function(dsuid, dsmdsuid, timeout,
                                                   callback)
{
    return Ext.Ajax.request(
    {
        url: '/dsa/json/device/testDevicePresence',
        disableCaching: true,
        method: "GET",
        params:
        {
            dsuid: dsuid,
            dsm_dsuid: dsmdsuid,
            timeout: timeout
        },
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data.present);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not start device presence test") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not start device presence test") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

// callback(success, errmsg)
dSA.functions.AbortTask = function(task_id, callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/task/cancel',
        disableCaching: true,
        method: 'GET',
        params:
        {
            id : task_id
        },
        success: function(response, opts)
        {
            try
            {
                dSA.util.checkResponse(response);
                if (callback !== undefined)
                {
                    callback(true);
                }
            }
            catch (error)
            {
                if (callback !== undefined)
                {
                    callback(false, error);
                }
            }
        },
        failure: function(response, opts)
        {
            if (callback !== undefined)
            {
                callback(false, dSA.util.failureMessage(response));
            }
        }
    });
};

dSA.functions.GetTaskStatus = function(task_id, callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/task/status',
        disableCaching: true,
        method: 'GET',
        params:
        {
            id : task_id
        },
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data);
                }
            }
            catch (error)
            {
                if (callback !== undefined)
                {
                    callback(false, error);
                }
            }
        },
        failure: function(response, opts)
        {
            if (callback !== undefined)
            {
                callback(false, dSA.util.failureMessage(response));
            }
        }
    });
};

// callback(success, taskdata)
dSA.functions.GetCurrentTask = function(callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/task/getCurrent',
        disableCaching: true,
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not get current task information") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }

        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not get current task information") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

dSA.functions.BlinkLEDonDSM = function(dsuid)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/dsm/blink',
        disableCaching: true,
        method: 'GET',
        params: { dsuid : dsuid },
        success: function(response, opts)
        {
            try
            {
                dSA.util.checkResponse(response);
                dSA.MessageBus.fireEvent('statusmessage',
                    dSA._("dSM LED is now blinking"));
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not blink LED on dSM") +
                    dSA.util.colon(error));
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not blink LED on dSM") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
        }
    });
};

dSA.functions.StartDeviceMonitor = function(callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/hardware/testDeviceMonitor',
        disableCaching: true,
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                dSA.MessageBus.fireEvent('statusmessage',
                    dSA._("Activated device monitor."));
                var data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data.task);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not activate device monitor") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not activate device monitor") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

dSA.functions.GetDeviceMonitorStatus = function(id, callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/hardware/testDeviceMonitorStatus',
        disableCaching: true,
        params: { id: id },
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not receive device information") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not receive device information") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

dSA.functions.GetDevice = function(dsuid, dsm_dsuid, callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/hardware/getDevice',
        disableCaching: true,
        params: { dsuid: dsuid, dsm: dsm_dsuid },
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                var data;

                data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data);
                }
            }
            catch (error)
            {
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not receive device information") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

dSA.functions.GetDSMLED = function(dsm_dsuid, callback, silent)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/dsm/getLedInfo',
        disableCaching: true,
        params: { dsuid: dsm_dsuid },
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                var data;

                data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data);
                }
            }
            catch (error)
            {
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            if (silent !== true)
            {
                Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not query dSM LED information") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            }
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

dSA.functions.PollForUpdateDeviceTaskStatus = function()
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/task/status',
        disableCaching: true,
        params: { type: dSA.config.TaskTypes.DEVICE_UPDATE_TASK },
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (data.progress < 100)
                {
                    dSA.MessageBus.fireEvent('statusmessage',
                            dSA._("Devices are being updated.") + ' ' +
                            data.progressInfo);
                    // 10 seconds when update is active
                    dSA.functions.PollForUpdateDeviceTaskStatus.defer(10000);
                }
                else
                {
                    // 20 seconds when update is inactive
                    dSA.functions.PollForUpdateDeviceTaskStatus.defer(10000);
                }
            }
            catch (error)
            {
                // 30 seconds in case of errors
                dSA.functions.PollForUpdateDeviceTaskStatus.defer(30000);
            }
        },
        failure: function(response, opts)
        {
            // 30 seconds in case of errors
            dSA.functions.PollForUpdateDeviceTaskStatus.defer(30000);
        }
    });
};

dSA.functions.LoadRegistrationMode = function(dsm_dsuid, callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/dsm/getDeviceRegistrationMode',
        disableCaching: true,
        params: { dsuid : dsm_dsuid },
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not get registration mode") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                      dSA._("Could not get registration mode") +
                      dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

dSA.functions.SetRegistrationMode = function(dsm_dsuid, action, callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/dsm/setDeviceRegistrationMode',
        disableCaching: true,
        params: { dsuid : dsm_dsuid, ignoreActionsFromNewDevices: action },
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                dSA.util.checkResponse(response);
                if (callback !== undefined)
                {
                    callback(true);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not set registration mode") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                      dSA._("Could not set registration mode") +
                      dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

dSA.functions.LoadStructure = function(callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/hardware/get',
        disableCaching: true,
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                var data;

                data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data);
                }
            }
            catch (error)
            {
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            if (silent !== true)
            {
                Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not query dSM information") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            }
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

dSA.functions.LoaddSMUpstreamFrequencies = function(callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/dsm/getUpstreamFrequency',
        disableCaching: true,
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                var data;

                data = dSA.util.getData(response);
                if (callback !== undefined)
                {
                    callback(true, data);
                }
            }
            catch (error)
            {
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            if (silent !== true)
            {
                Ext.Msg.alert(dSA._("Error"),
                          dSA._("Could not query dSM frequency information") +
                          dSA.util.colon(dSA.util.failureMessage(response)));
            }
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};

dSA.functions.SavedSMUpstreamFrequency = function(dsm_dsuid, frequency, callback)
{
    Ext.Ajax.request(
    {
        url: '/dsa/json/dsm/setUpstreamFrequency',
        params: { dsuid: dsm_dsuid, frequency: frequency },
        disableCaching: true,
        method: 'GET',
        success: function(response, opts)
        {
            try
            {
                dSA.util.checkResponse(response);
                if (callback !== undefined)
                {
                    callback(true);
                }
            }
            catch (error)
            {
                Ext.Msg.alert(dSA._("Error"),
                    dSA._("Could not set upstream frequency") +
                    dSA.util.colon(error));
                if (callback !== undefined)
                {
                    callback(false);
                }
            }
        },
        failure: function(response, opts)
        {
            Ext.Msg.alert(dSA._("Error"),
                      dSA._("Could not set upstream frequency") +
                      dSA.util.colon(dSA.util.failureMessage(response)));
            if (callback !== undefined)
            {
                callback(false);
            }
        }
    });
};
